pitchtools.MelodicChromaticInterval
===================================

.. inheritance-diagram:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.cents

   .. note:: Inherited from :py:class:`pitchtools._Interval <abjad.tools.pitchtools._Interval._Interval._Interval>`

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.chromatic_interval_number

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.direction_number

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.direction_string

   .. note:: Inherited from :py:class:`pitchtools._MelodicInterval <abjad.tools.pitchtools._MelodicInterval._MelodicInterval._MelodicInterval>`

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.harmonic_chromatic_interval

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.interval_class

   .. note:: Inherited from :py:class:`pitchtools._Interval <abjad.tools.pitchtools._Interval._Interval._Interval>`

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.melodic_chromatic_interval_class

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.number

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. autoattribute:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.semitones

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__abs__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__add__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__eq__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__float__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__ge__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__gt__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__hash__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__int__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__le__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__lt__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__ne__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__neg__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__repr__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__str__

.. automethod:: abjad.tools.pitchtools.MelodicChromaticInterval.MelodicChromaticInterval.MelodicChromaticInterval.__sub__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`
